crabnet.data.benchmark\_data.aflow\_\_Egap package
==================================================

Module contents
---------------

.. automodule:: crabnet.data.benchmark_data.aflow__Egap
   :members:
   :undoc-members:
   :show-inheritance:
